<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      :inline="true"
      v-show="showSearch"
      label-width="120px"
    >
      <el-form-item label="付款医院" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入姓名"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="收款年度" prop="donationcategory">
        <el-input
          v-model="queryParams.donationcategory"
          placeholder="请输入捐献类别"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="收款状态" prop="chargeamount">
        <el-input
          v-model="queryParams.chargeamount"
          placeholder="请输入费用金额"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:donorcharge:add']"
          >新增</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:donorcharge:edit']"
          >修改</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:donorcharge:remove']"
          >删除</el-button
        >
      </el-col>

      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="donorchargeList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column
        label="申请时间"
        align="center"
        prop="createTime"
        width="180"
      >
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.createTime, "{y}-{m}-{d}") }}</span>
        </template>
      </el-table-column>
      <el-table-column label="收款单号" align="center" prop="paymentno" />
      <el-table-column
        label="付款医院"
        width="180"
        align="center"
        prop="hospitalname"
      />

      <el-table-column label="状态" align="center" prop="paystatus">
        <template slot-scope="scope">
          <dict-tag
            :options="dict.type.sys_gathering"
            :value="scope.row.paystatus"
          />
        </template>
      </el-table-column>
      <el-table-column
        label="应收金额"
        align="center"
        prop="receivableamount"
      />
      <el-table-column label="已收金额" align="center" prop="receivedamount" />
      <el-table-column
        label="收款日期"
        width="180"
        align="center"
        prop="receivedtime"
      />
      <el-table-column label="经办人" align="center" prop="updateBy" />
      <el-table-column label="操作" width="280" align="center">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:donorcharge:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleDetail(scope.row)"
            v-hasPermi="['system:donorcharge:edit']"
            >详情</el-button
          >
          <el-button
            size="mini"
            type="text"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:donorcharge:remove']"
            ><span class="button-delete"
              ><i class="el-icon-delete"></i>删除</span
            ></el-button
          >
          <el-button
            size="mini"
            type="primary"
            @click="download(scope.row)"
            icon="el-icon-download"
            circle
          ></el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <el-dialog
      :visible.sync="showSelectionDialog"
      :close-on-click-modal="false"
      :title="'请选择捐献案例'"
      width="500px"
      style="text-align: center"
      v-loading="loading"
    >
      <el-form ref="selectionForm" :model="selectionForm">
        <el-row>
          <el-form-item
            align="left"
            label="医疗机构"
            prop="treatmenthospitalno"
          >
            <org-selecter
              ref="addOrgSelect"
              :org-type="'4'"
              v-model="selectionForm.donorid"
            />
          </el-form-item>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="showSelectionDialog = false">取 消</el-button>
        <el-button type="primary" @click="confirmSelection()">确 定</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import { listDonatebaseinfo } from "@/api/project/donatebaseinfo";
import {
  listDonorcharge,
  getDonorcharge,
  delDonorpayment,
  addDonorcharge,
  updateDonorcharge,
  exportDonorcharge,
  listDonorpayment,
  dyDonorpayment
} from "@/api/project/donorcharge";
import { listOrganization } from "@/api/project/organization";

import OrgSelecter from "@/views/project/components/orgselect";

export default {
  name: "Donorcharge",
  dicts: ["sys_gathering"],
  components: {
    OrgSelecter
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      //当前案例id
      curInfoId: 0,
      // 捐献案例器官列表格数据
      donorchargeList: [],
      donorchargerogans: [],

      //捐献案例选择
      showSelectionDialog: false,
      donorlist: [],
      donorinfolist: [],
      selectionForm: {
        index: null,
        donorid: null,
        donorname: null
      },
      loadingdonorlist: false,

      // 弹出层标题
      title: "",
      // 是否显示弹出层
      // 查询费用表参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        infoid: null,
        name: null,
        donationcategory: null,
        donateorgan: null,
        chargeamounted: null
      },
      //查询案例参数
      donorParams: {
        pageNum: 1,
        pageSize: 1000
      },
      // 查询费用器官表参数
      organParams: {
        pageNum: 1,
        pageSize: 10,
        donorchargeid: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {}
    };
  },
  created() {
    this.getList();
  },

  methods: {
    //专家/医疗机构/费用报销机构选择
    confirmSelection() {
      var curdonorinfo = null;
      console.log(this.selectionForm.donorid, "donorid");
      //从案例列表获取信息
      this.donorinfolist.map(item => {
        if (this.selectionForm.donorid == item.id) {
          curdonorinfo = item;
        }
      });
      let searchData = {
        organizationid: this.selectionForm.donorid //传入的类型
      }; //搜索条件
      listOrganization(searchData).then(res => {
        if (res.code == 200) {
          curdonorinfo = res.rows[0];
          this.$router.push({
            path: "/cost/particulars",
            query: { id: 0, operation: "add", data: curdonorinfo }
          });
        } else {
          this.$message.error(res.msg);
        }
      });
      this.showSelectionDialog = false;
    },

    /** 查询捐献案例器官列列表 */
    getList() {
      this.loading = true;
      listDonorpayment(this.queryParams).then(response => {
        this.donorchargeList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

    // 表单重置
    reset() {
      this.form = {
        id: null,
        infoid: null,
        donateno: null,
        donatetime: null,
        name: null,
        borthdate: null,
        sex: null,
        age: null,
        donationcategory: null,
        donateorgan: null,
        chargeamount: null,
        chargeamounted: null,
        remark: null,
        delFlag: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.selectionForm.index = null;
      this.selectionForm.donorid = null;
      this.selectionForm.donorname = null;

      if (this.donorlist[0]) {
        this.showSelectionDialog = true;
      } else {
        //获取捐献案例列表
        if (this.donorlist.length > 0) {
        } else {
          this.loading = true;
          listDonatebaseinfo(this.donorParams).then(res => {
            // this.donorinfolist = res.rows;
            res.rows.forEach(item => {
              if (item.workflow >= 6) {
                this.donorinfolist.push(item);
              }
            });

            this.donorinfolist.forEach(item1 => {
              this.donorlist.push({
                donorid: item1.id,
                donorname: item1.name
              });
            });
            console.log(this.donorinfolist, " this.donorinfolist");
            this.loading = false;
          });
        }

        this.showSelectionDialog = true;
      }
    },

    /** 修改按钮操作 */
    handleUpdate(row) {
      this.$router.push({
        path: "/cost/particulars",
        query: { id: row.id, operation: "update", data: row }
      });
    },

    /** 详情查看按钮操作 */
    handleDetail(row) {
      this.$router.push({
        path: "/cost/particulars",
        query: { id: row.id, operation: "detail", data: row }
      });
    },
    // 打印
    download(row) {
      dyDonorpayment(row.id).then(res => {});
    },

    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除捐献案例器官列编号为"' + ids + '"的数据项？')
        .then(function() {
          return delDonorpayment(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },

    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$modal
        .confirm("是否确认导出所有捐献案例器官列数据项？")
        .then(() => {
          this.exportLoading = true;
          return exportDonorcharge(queryParams);
        })
        .then(response => {
          this.$download.name(response.msg);
          this.exportLoading = false;
        })
        .catch(() => {});
    }
  }
};
</script>
<style scoped>
/* @import url(); 引入公共css类 */
.button-delete {
  color: rgb(236, 69, 69);
}
</style>
